package com.persagy.apm.energyalarmstarter.alarmdata.service;

import com.persagy.apm.energyalarmstarter.alarmdata.feign.AlarmUrlParam;
import com.persagy.apm.energyalarmstarter.alarmdata.feign.DmpResult;
import com.persagy.apm.energyalarmstarter.alarmdata.feign.client.AlarmClient;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.alarmconfig.AddAlarmConfigDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.common.QueryAlarmConfigDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.common.QueryDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.vo.AlarmConfigItem;
import com.persagy.apm.energyalarmstarter.alarmdata.model.vo.DmpUpsertVO;
import com.persagy.apm.energyalarmstarter.alarmdata.utils.DmpResultUtil;
import com.persagy.apm.energyalarmstarter.alarmdata.utils.Obj2JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.configurationprocessor.json.JSONArray;
import org.springframework.boot.configurationprocessor.json.JSONObject;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 报警条件service类
 *
 * @author lixing
 * @version V1.0 2021/9/15 8:47 下午
 **/
@Service
public abstract class AlarmConfigServiceImpl {
    @Autowired
    AlarmClient alarmClient;

    /**
     * 初始化请求中台接口url中的参数
     *
     * @return url中的参数对象
     * @author lixing
     * @version V1.0 2021/9/15 11:25 下午
     */
    public abstract AlarmUrlParam initUrlParams();

    /**
     * 创建报警条件
     *
     * @param addAlarmConfigDTO 入参
     * @return 报警条件id
     * @author lixing
     * @version V1.0 2021/9/15 9:22 下午
     */
    public DmpResult<DmpUpsertVO> create(AddAlarmConfigDTO addAlarmConfigDTO) throws Exception{
        JSONObject jsonObject = Obj2JSONObject.convert(addAlarmConfigDTO);
        DmpResult<JSONObject> alarmConfig = alarmClient.createAlarmConfig(initUrlParams(), jsonObject);
        return DmpResultUtil.singleConvert(alarmConfig, DmpUpsertVO.class);
    }

    /**
     * 查询报警条件
     *
     * @param queryAlarmConfigDTO 入参
     * @return 报警条件列表（不分页）
     * @author lixing
     * @version V1.0 2021/9/16 9:51 上午
     */
    public DmpResult<List<AlarmConfigItem>> query(QueryAlarmConfigDTO queryAlarmConfigDTO) throws Exception {
        QueryDTO<QueryAlarmConfigDTO> queryDTO = new QueryDTO<>();
        return query(queryDTO);
    }

    /**
     * 分页查询报警条件
     *
     * @param queryAlarmConfigDTO 入参
     * @return 报警条件列表（分页）
     * @author lixing
     * @version V1.0 2021/9/16 9:51 上午
     */
    public DmpResult<List<AlarmConfigItem>> query(QueryDTO<QueryAlarmConfigDTO> queryAlarmConfigDTO) throws Exception {
        JSONObject jsonObject = Obj2JSONObject.convert(queryAlarmConfigDTO);
        DmpResult<JSONArray> result = alarmClient.queryAlarmConfig(initUrlParams(), jsonObject);
        return null;
    }

}
